 /* ============================================================================
 * File Name: FracPWM DAC_01c_basic
 * 
 * Description:
 *   Demonstrates 16-bit DAC, with output range 0-Vdd made using Fractional PWM 
 *   Uses 8-bit PWM modulated by 8-bit first-order DeltaSigma Modulator (DSM)
 *   The MSB is provided by PWM, the LSB is provided by DSM
 *   PWM output is filtered using 1-st order RC filter
 *
 * Credits:
 *   uses 8-bit 1-st order DeltaSigma Modulator ZhuPDM8 by FY_ZHU, 2013
 *   https://community.cypress.com/t5/PSoC-4-MCU/A-PWM-Algorithm-Realized-With-Only-One-Add-Instruction/td-p/54385
 *   
 * 
 * Note:
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>


//===========================================
// Global variables
//===========================================

//===========================================
// Declarations
//===========================================
void SetValue(uint16 value);


void Init(void)
{   
    //CyGlobalIntEnable; //enable global interrupts.
    
    //DSM_1_Start(); // n/a
    PWM_1_Start();   // start PWM
    SetValue(32767); // set some value 0-65535 (0-Vdd)   
}


int main()
{      
    Init();
       
    for(;;) 
    {
    }

}


//==============================================================================
// 
//==============================================================================
void SetValue(uint16 value)
{
    uint8 lsb = value & 0xFF;
    uint8 msb = (value >> 8) & 0xFF;
    
    DSM_1_SetValue(lsb);
    PWM_1_WriteCompare1(msb);
    PWM_1_WriteCompare2(msb);  
}

/* [] END OF FILE */
